import turtle
import random
#main code
turtle.speed("fastest")
while True:
    turtle.goto(random.random(),random.random())
    turtle.penup()
    turtle.pendown()
    turtle.color(random.random(),random.random(),random.random())
    turtle.begin_fill()
    turtle.forward(90)
    turtle.shape("turtle")
    turtle.color(random.random(),random.random(),random.random())
    turtle.pencolor(random.random(),random.random(),random.random())
    turtle.left(random.random())
    turtle.forward(90)
    turtle.left(random.random())
    turtle.pencolor(random.random(),random.random(),random.random())
    turtle.forward(random.random())
    turtle.left(random.random())
    turtle.pencolor(random.random(),random.random(),random.random())
    turtle.forward(90)
    turtle.end_fill()
    turtle.color(random.random(),random.random(),random.random())



import random
from tkinter import Button,HIDDEN,NORMAL,DISABLED,Tk,messagebox
words = ['pizza','fairy','teeth','shirt','otter','plane','sleepy','slow',
         'smelly','wet','fat','red','orange','yellow','green','blue','purple','fluffy',
         'white','pround','brave','apple','dinosaur','ball','toaster','goat','dragon','hammer','duck'
         'panda']
attempt = 0
secret_word = random.choice(words)
wordsf = list(secret_word)
clue = list(len(wordsf) * '?')
present = list('????????????0')
heart_symbol = u'\u2764'
presents = 0
guessed_word_correctly = False
def update_clue(guessed_leter,secret_word,clue):
    index = 0
    while index < len(secret_word):
        if guessed_leter == secret_word[index]:
            clue[index] = guessed_leter
        index = index + 1
def 金币系统(number_1,number_2):
    金币数量 = str(number_1 + number_2)
    金币数列表 = list(金币数)
    return 金币数列表[0]
level = input('please choose game difficulty: \na:easy \nb:normal \nc:hard\n:')
if level == 'a' or level == 'easy':
    lives = 12
elif level == 'b' or level == 'normal':
    lives = 9
else:
    lives = 6
while lives > 0:
    print(clue)
    print('金币数量:',present)
    print('Lives Left:'+ heart_symbol * lives)
    guess = input('Guess a leter or a whole word: ')
    if guess == secret_word:
        guessed_word_correctly = True
        break
    if guess in secret_word:
        update_clue(guess,secret_word,clue)
    else:
        print('Incorrect, you lose a life')
        lives -= 1
    attempt = attempt + 1
if guessed_word_correctly:
	print('you win!')
	if attempt <= 8:
		print('获得金币数：'+ str(attempt * 2 * 10000000))
		print('金币数量:',list(str(attempt * 2 * 10000000)))
	elif attempt > 8:
		print('获得金币数：'+ str(attempt * 4 * 1000000))
		print('金币数量:',list(str(attempt * 4 * 1000000)))
	else:
		print('获得金币数：'+ str(attempt * 8 * 100))
		print('金币数量:',list(str(attempt * 8 * 100)))
else:
    print('you lost')
print('The secret word was',secret_word)
se = input('你要不要用金币试玩更多好玩的作品? no or yes')
if se.lower() == 'yes':
    print('                        金币悬赏\n')
    print('!!!!!!!!!!!!!!!!!!!!!!!!!New!!!!!!!!!!!!!!!!!!!!!!!!!!')
    print('玩玩下面作品吧！')
    print('alien침입하다之4つの言語の会話')
    print('1982년에 당신은 외계인으로서 지구를 침입했지만 지구인들은 당신에게 우호를 표시했습니다.')
    print('\'>>>\'地球人の言うことを表す')
    welcome=input('>>>welcome,Ally Alien,what\'s your name?Can you tell me?I\'m kind!')
    print('>>>Say it again(\"あなたの気持ちが変わったかどうかを再確認するために\")')
    answer=input('>>>What\'s your name?')
    print('>>>Welcome ,'+answer+'， I\'m kind')
    play_answer=input('>>>Can you play with me?Yes or No')
    if play_answer.lower()=='no':
        print('I\'m disappointed')
    elif play_answer.lower()=='yes':
        print('We can get to the supermarket!')
        print('At the supermarket')
    else:
        print('At the supermarket')
        love_age=input('>>>what\'s your age?')
        print('>>>That\'s wonderful, how a great age! '+love_age)
        print('Thank you very much!')
        print('>>>You\'re welcome!')
    answer=input('what are you doing?get along well?time to attack?orスキップしない')
    if answer.lower()=='get along well':
        print('>>>私たちは日本に行って、中国に行って、イギリスに行って......')
    elif answer.lower()=='time to attack':
        print('Boon!数秒後、地球人は悲鳴をあげ、あなたも警察署に送られました(narration)')
    else:
        place=input(['go to the cinema?','go to the beach?','go to the bus stop,go to the garden,see the beautiful lake?'])
        if place.lower()=='go to tne cinema':
            print('>>>go!')
            print('At the cinema')
            print('Look,It\'s a tiger,It\'s jumping at me Ahhhhhhhhhhhh!')
            print('>>>Don\'t be afraid')
        else:
            print('>>>No,I can\'t catch the car')
            Refuse=('see you again')
            for char in Refuse:
                print(Refuse)
                break
else:
    Refuse=('OK,Bye',u'\u2764')
    for char in Refuse:
        print(Refuse)
        break



import random
def randomInt_Float(fromInt,toInt):
    randomnum = random.uniform(fromInt,toInt)
    return randomnum
def randomInt_Integers(fromInt,toInt):
    randomnumber = random.randint(fromInt,toInt)
    return randomnumber
def randomInt_type_MaxMinNumber():
    #使用循环取值支持输入，并检测异常，冒泡输入8位
    list_1 = list()
    try:
        for i in range(8):
            num = eval(input('请输入数字'))
            list_1.append(num)
        print(list_1)
        c = list_1[0]
        list_max = max(list_1)
        list_min = min(list_1)
        print('max:',list_max)
        print('min:',list_min)
    except Exception as e:
        print(e)
    return
def randomnumber_OneHundred():
    list_1 = list()
    index = 0
    for i in range(100):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_Ten():
    list_1 = list()
    index = 0
    for i in range(10):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneHhousand():
    list_1 = list()
    index = 0
    for i in range(1000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_TenHhousand():
    list_1 = list()
    index = 0
    for i in range(10000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneHundredHhousand():
    list_1 = list()
    index = 0
    for i in range(100000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneMillion():
    list_1 = list()
    index = 0
    for i in range(1000000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_TenMillion():
    list_1 = list()
    index = 0
    for i in range(10000000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneHundredMillion():
    list_1 = list()
    index = 0
    for i in range(100000000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneHundredMillion():
    list_1 = list()
    index = 0
    for i in range(100000000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_OneBillion():
    list_1 = list()
    index = 0
    for i in range(1000000000):
        index = index + 1
        list_1.append(index)
    number = random.choice(list_1)
    return number
def randomnumber_TenBillion():
    number = random.randint(1,10000000000)
    return number
def randomnumber_OneHundredBillion():
    number = random.randint(1,10000000000)
    return number



from itertools import cycle
from random import randrange
from tkinter import Canvas,Tk,messagebox,font,PhotoImage
import time

canvas_width=800
canvas_height=400

root=Tk()
root.title('COPISEDED MADE GAMING')
c=Canvas(root,width=canvas_width,height=canvas_height,background='deep sky blue')
c.create_oval(-5,canvas_height-100,canvas_width+5,\
                               canvas_height+5,fill='sea green',width=0)
c.create_oval(-80,-80,120,120,fill='orange',width=0)
c.pack()

color_cycle=cycle(['light blue','light pink','light green','light yellow','light cyan'])
egg_width=45
egg_height=55
egg_score=10
egg_speed=500
egg_interval=4000
difficulty_factor=0.95

catcher_color='red'
catcher_width=100
catcher_height=100
catcher_start_x=canvas_width/2-catcher_width/2
catcher_start_y=canvas_height-catcher_height-20
catcher_start_x2=catcher_start_x+catcher_width
catcher_start_y2=catcher_start_y+catcher_height

catcher=c.create_arc(catcher_start_x,catcher_start_y,\
                     catcher_start_x2,catcher_start_y2,start=200,extent=140,\
                     style='arc',outline=catcher_color,width=3)

game_font=font.nametofont('TkFixedFont')
game_font.config(size=18)

score=0
score_text=c.create_text(10,10,anchor='nw',font=game_font,fill='darkblue',\
                                                     text='Score: '+str(score))
lives_remaining=3
lives_text=c.create_text(canvas_width -10,10,anchor='ne',font=game_font,fill='darkblue',\
                         text='Lives: '+str(lives_remaining))
eggs= []
def create_egg():
    x=randrange(10,740)
    y=40
    new_egg=c.create_oval(x,y,x+egg_width,y+egg_height,fill=next(color_cycle),width=0)
    eggs.append(new_egg)
    root.after(egg_interval,create_egg)

def move_eggs():
    for egg in eggs:
        (egg_x,egg_y,egg_x2,egg_y2)=c.coords(egg)
        c.move(egg,0,10)
        if egg_y2>canvas_height:
            egg_dropped(egg)
    root.after(egg_speed,move_eggs)

def egg_dropped(egg):
    eggs.remove(egg)
    c.delete(egg)
    lose_a_life()
    if lives_remaining==0:
        messagebox.showinfo('Game Over!','Final Score: '+str(score))
        root.destroy()

def lose_a_life():
    global lives_remaining
    lives_remaining-=1
    c.itemconfigure(lives_text,text='lives: '+str(lives_remaining))
    
def check_catch():
    (catcher_x,catcher_y,catcher_x2,catcher_y2)=c.coords(catcher)
    for egg in eggs:
        (egg_x,egg_y,egg_x2,egg_y2)=c.coords(egg)
        if catcher_x < egg_x and egg_x2 <catcher_x2 and catcher_y2-egg_y2<40:
            eggs.remove(egg)
            c.delete(egg)
            increase_score(egg_score)
    root.after(100,check_catch)
    
def increase_score(points):
    global score,egg_speed,egg_interval
    score+=points
    egg_speed=int(egg_speed*difficulty_factor)
    egg_interval=int(egg_interval*difficulty_factor)
    c.itemconfigure(score_text,text='Score: '+str(score))

def move_left(event):
    (x1,y1,x2,y2)=c.coords(catcher)
    if x1>0:
        c.move(catcher,-20,0)

def move_right(event):
    (x1,y1,x2,y2)=c.coords(catcher)
    if x2<canvas_width:
        c.move(catcher,20,0)

c.bind('<Left>',move_left)
c.bind('<Right>',move_right)
c.focus_set()

root.after(1000,create_egg)
root.after(1000,move_eggs)
root.after(1000,check_catch)

root.mainloop()



import random
import turtle as t

t.bgcolor('yellow')

caterpillar=t.Turtle()
caterpillar.shape('square')
caterpillar.color('red')
caterpillar.speed(0)
caterpillar.penup()
caterpillar.hideturtle()

caterpillar2=t.Turtle()
caterpillar2.shape('square')
caterpillar2.color('sea green')
caterpillar2.speed(0)
caterpillar2.penup()
caterpillar2.hideturtle()

leaf=t.Turtle()
leaf_shape=((0,0),(14,2),(18,6),(20,20),(6,18),(2,14))
t.register_shape('leaf',leaf_shape)
leaf.shape('leaf')
leaf.color('green')
leaf.speed(0)
leaf.penup()
leaf.hideturtle()

game_started=False
text_turtle=t.Turtle()
text_turtle.write('Press SPACE to start',align='center',font=('Arial',16,'bold'))
text_turtle.hideturtle()

score_turtle=t.Turtle()
score_turtle.hideturtle()
score_turtle.speed(0)

def outside_window(caterpillar):
    left_wall=-t.window_width()/2
    right_wall=t.window_width()/2
    top_wall=t.window_height()/2
    bottom_wall=-t.window_height()/2
    (x,y)=caterpillar.pos()
    outside=x<left_wall or x>right_wall or \
            y<bottom_wall or y>top_wall
    return outside

def game_over():
    caterpillar.color('yellow')
    caterpillar2.color('yellow')
    leaf.color('yellow')
    t.penup()
    t.hideturtle()
    t.write('GAME OVER!',align='center',font=('Arial',30,'normal'))
    

def display_score(current_score):
    score_turtle.clear()
    score_turtle.penup()
    x=(t.window_width()/2)-50
    y=(t.window_height()/2)-50
    score_turtle.setpos(x,y)
    score_turtle.write(str(current_score),align='right',font=('Arial',40,'bold'))

def place_leaf():
    leaf.ht()
    leaf.setx(random.randint(-200,200))
    leaf.sety(random.randint(-200,200))
    leaf.st()

def start_game():
    global game_started
    if game_started:
        return
    game_started=True

    score=0
    text_turtle.clear()

    caterpillar_speed=2
    caterpillar_length=3
    caterpillar.shapesize(1,caterpillar_length,1)
    caterpillar.showturtle()
    caterpillar2.shapesize(1,caterpillar_length,1)
    caterpillar.setheading(180)
    caterpillar2.showturtle()
    display_score(score)
    place_leaf()

    while True:
        caterpillar.forward(caterpillar_speed)
        caterpillar2.forward(caterpillar_speed)
        if caterpillar.distance(leaf)<20 or caterpillar2.distance(leaf)<20:
            place_leaf()
            caterpillar_length=caterpillar_length+1
            caterpillar.shapesize(1,caterpillar_length,1)
            caterpillar2.shapesize(1,caterpillar_length,1)
            caterpillar_speed=caterpillar_speed+1
            score=score+10
            display_score(score)
        if outside_window(caterpillar) or outside_window(caterpillar2):
            game_over()
            break
def move_up():
    if caterpillar.heading()==0 or caterpillar.heading()==180:
        caterpillar.setheading(90)
        
def move_down():
    if caterpillar.heading()==0 or caterpillar.heading()==180:
        caterpillar.setheading(270)
        
def move_left():
    if caterpillar.heading()==90 or caterpillar.heading()==270:
        caterpillar.setheading(180)
        
def move_right():
    if caterpillar.heading()==90 or caterpillar.heading()==270:
        caterpillar.setheading(0)

def caterpillar2_move_up():
    if caterpillar2.heading()==0 or caterpillar2.heading()==180:
        caterpillar2.setheading(90)
        
def caterpillar2_move_down():
    if caterpillar2.heading()==0 or caterpillar2.heading()==180:
        caterpillar2.setheading(270)
        
def caterpillar2_move_left():
    if caterpillar2.heading()==90 or caterpillar2.heading()==270:
        caterpillar2.setheading(180)
        
def caterpillar2_move_right():
    if caterpillar2.heading()==90 or caterpillar2.heading()==270:
        caterpillar2.setheading(0)
        
t.onkey(start_game,'space')
t.onkey(move_up,'Up')
t.onkey(move_right,'Right')
t.onkey(move_down,'Down')
t.onkey(move_left,'Left')

t.onkey(caterpillar2_move_up,'1')
t.onkey(caterpillar2_move_right,'4')
t.onkey(caterpillar2_move_down,'2')
t.onkey(caterpillar2_move_left,'3')
t.listen()
t.listen()
t.mainloop()



import random
def guessGame_1_10_Easy():
    number = random.randint(1,10)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

        
def guessGame_1_100_Easy():
    number = random.randint(1,100)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            elif ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
def guessGame_1_1000_Easy():
    number = random.randint(1,1000)

    guess = input('请输入你的数字:')
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        elif ettempt == 3:
            print('sorry wrong,the collect int is: '+str(number))
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_10000_Easy():
    number = random.randint(1,10000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100000_Easy():
    number = random.randint(1,100000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            elif ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_1000000_Easy():
    number = random.randint(1,1000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_10000000_Easy():
    number = random.randint(1,10000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100000000_Easy():
    number = random.randint(1,100000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_1000000000_Easy():
    number = random.randint(1,10000000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_10000000000_Easy():
    number = random.randint(1,10000000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_100000000000_Easy():
    number = random.randint(1,100000000000)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_999999999999_Easy():
    number = random.randint(1,999999999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_9_Easy():
    number = random.randint(1,9)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_99_Easy():
    number = random.randint(1,99)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_999_Easy():
    number = random.randint(1,999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_9999_Easy():
    number = random.randint(1,9999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_99999_Easy():
    number = random.randint(1,99999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            elif ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_999999_Easy():
    number = random.randint(1,999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            elif ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_9999999_Easy():
    number = random.randint(1,9999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_99999999_Easy():
    number = random.randint(1,99999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_999999999_Easy():
    number = random.randint(1,999999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))


def guessGame_1_9999999999_Easy():
    number = random.randint(1,9999999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))

def guessGame_1_99999999999_Easy():
    number = random.randint(1,99999999999)
    ettempt = 0
    Round = 3
    while ettempt != 3 and Round == 3:
        guess = input('请输入你的数字:')
        if number == int(guess):
            print('太棒了，你猜对了!')
            Round = Round - 1
        else:
            print('sorry wrong,please guess again')
            if number < int(guess):
                print('you\'s guess are too big')
            else:
                print('you\'s guess are too small')
            ettempt = ettempt + 1
            if ettempt == 3:
                print('sorry wrong,the collect int is: '+str(number))



import random
import time
from tkinter import Tk,Button,DISABLED,messagebox
from pygame import mixer

mixer.init()
beep=mixer.Sound(os.path.abspath('MHCInc/200bpm%E6%AD%BB%E4%BA%A1%E4%B9%8B%E6%9B%B2 2.flac'))
beep.play()
time.sleep(5)

def show_symbol(x,y):
    global first
    global previousX,previousY
    global moves
    global pairs
    buttons[x,y]['text'] = button_symbols[x,y]
    buttons[x,y].update_idletasks()

    if first:
        previousX = x
        previousX = y
        first = False
        moves = moves+1
    elif previousX != x or previousY != y:
        if buttons[previousX,previousY]['text'] != buttons[x,y]['text']:
            time.sleep(0.5)
            buttons[previousX,previousY]['text'] = ''
            buttons[x,y]['text']=''
        else:
            buttons[previousX,previousY]['command']=DISABLED
            buttons[x,y]['command']=DISABLED
            pairs = pairs+1
            if pairs == len(buttons)/2:
                messagebox.showinfo('Matching','number of moves: '+
                                    str(moves),command=close_window)
        first = True

def close_window(self):
    root.destroy()

root=Tk()
root.title('Matchmaker')
root.resizable(width=False,height=False)

buttons = {}
first = True
previousX = 0
previousY = 0
moves = 0
pairs = 0
button_symbols = {}
symbols = [u'\u2702',u'\u2702',u'\u2705',u'\u2705',u'\u2708',u'\u2708',\
        u'\u2709',u'\u2709',u'\u270A',u'\u270A',u'\u270B',u'\u270B',\
        u'\u270C',u'\u270C',u'\u270F',u'\u270F',u'\u2712',u'\u2712',\
        u'\u2714',u'\u2714',u'\u2716',u'\u2716',u'\u2728',u'\u2728',\
        u'\u2733',u'\u2733',u'\u2734',u'\u2734',u'\u2744',u'\u2744']
random.shuffle(symbols)

for x in range(6):
    for y in range(5):
        button = Button(command=lambda x=x,y=y: show_symbol(x,y),width=3,height=3)
        button.grid(column=x,row=y)
        buttons[x,y] = button
        button_symbols[x,y] = symbols.pop()

root.mainloop()



import turtle as t
import time

def rectangle(horizontal,vertical,color):
    t.pendown()
    t.pensize(1)
    t.color(color)
    t.begin_fill()
    for counter in range(1,3):
        t.forward(horizontal)
        t.right(90)
        t.forward(vertical)
        t.right(90)
    t.end_fill()
    t.penup()

t.penup()
t.speed(0)
t.bgcolor('Dodger blue')
t.shape('turtle')

#feet
t.goto(-100,-150)
rectangle(50,20,'hot pink')
t.goto(-30,-150)
rectangle(50,20,'hot pink')

#legs
t.goto(-25,-50)
rectangle(15,100,'skyblue1')
t.goto(-55,-50)
rectangle(-15,100,'skyblue1')

#body
t.goto(-90,100)
rectangle(100,150,'hot pink')

#arms
t.goto(-150,70)
rectangle(60,15,'pink')
t.goto(-150,110)
rectangle(15,40,'white')

t.goto(10,70)
rectangle(60,15,'pink')
t.goto(55,110)
rectangle(15,40,'white')

#neck
t.goto(-50,120)
rectangle(15,20,'white')

#head
t.goto(-85,170)
rectangle(80,50,'pink')

#eyes
t.goto(-60,160)
rectangle(30,10,'white')
t.goto(-58,160)
rectangle(5,5,'goldenrod')
t.goto(-41,160)
rectangle(5,5,'goldenrod')

#mouth
t.goto(-65,135)
t.left(6)
rectangle(40,5,'red')

#middle finger
t.goto(-145,120)
rectangle(3,10,'white')

t.write("你过来呀！",align='right',font=('Arial',40,'bold'))
t.hideturtle()



import tkinter as tit
from tkinter import simpledialog,messagebox,Canvas
from pygame import mixer
import time
from os.path import join

root = tit.Tk()
root.title('PHYSICAL CONDITION APPLET')
c = tit.Canvas(root,width=800,height=800,bg='black')
c.pack()
c.create_text(50,50,anchor='nw',fill='orange',\
              font='Arial 28 bold underline',text='Welcome to the physical condition applet')
mixer.init()
beep=mixer.Sound(os.path.abspath('MHCInc/200bpm%E6%AD%BB%E4%BA%A1%E4%B9%8B%E6%9B%B2 2.flac'))
beep.play()
time.sleep(5)

def write():
        print('Creating a new file')
        name = 'APPLET'+'.txt'  # Name of text file coerced with +.txt
        try:
           file = open(name,'w')
           file.write("influenza/A good rest is all you need,and drink more water.\ncommon cold/Please drink more hot water,and wear more warm clothes.\nphysical fitness/Please drink more hot water to prevent cold.\nrun a fever/Please go to the hospital for treatment.")
           file.close()

        except Exception as e:
            print(e)
            print('Something went wrong! Cannot tell what?')
def get_name():
    name = tit.simpledialog.askstring('Visiting patients','What\'s your name: ')
    return name

def get_task():
    task = tit.simpledialog.askstring('Task','What\'s your physical condition?: ')
    return task

def get_physical_condition():
    gpc = tit.simpledialog.askstring('Task','Do you have any other discomfort? ')
    return gpc

def yes_text():
    Yes_text = tit.simpledialog.askstring('Task','Tell me about it,please! ')
    return Yes_text

def read_from_file():
    try:
        with open('APPLET.txt') as file:
            for line in file:
                line = line.rstrip('\n')
                condition,solution = line.split('/')
                the_physical_condition[condition] = solution
    except Exception as e:
        print(e)
        print("请下载源文件，并拖放到文稿文件夹下")
def write_to_file(solution_name,condition_name):
    try:
        with open('APPLET.txt','a')as file:
            file.write('\n'+ solution_name + '/' + condition_name)
    except Exception as e:
        print(e)
        print("请下载源文件，并拖放到文稿文件夹下")
            
    
write()
the_physical_condition={}
read_from_file()
name=get_name()
task=get_task()
gpc=get_physical_condition()
ytt=yes_text()

while True:
    name
    c.create_text(50,100,anchor='w',fill='Thistle',\
                  font='Arial 28 bold',text='hello, %s' % (name))
    task
    if task == 'run a fever':
        not_bad_message=('Please go to the hospital for treatment.')
        c.create_text(50,130,anchor='w',fill='lightblue',\
                      font='Arial 28 bold',text=not_bad_message)
        gpc
    elif task == 'common cold':
        good_message='Please drink more hot water,and wear more warm clothe\n-s,around the scarf.'
        c.create_text(50,130,anchor='w',fill='lightblue',\
                      font='Arial 28 bold',text=good_message)
        gpc
    else:
        display='Please drink more hot water to prevent cold.'
        c.create_text(50,130,anchor='w',fill='lightblue',\
                      font='Arial 28 bold',text=display)
        gpc
    if gpc =='yes':
        ytt
    else:
        break
    if ytt in the_physical_condition:
        result = the_physical_condition[ytt]
        c.create_text(50,160,anchor='w',fill='lightblue',\
                      font='Arial 28 bold',text=ytt+'ought to '+result+'!')
    else:
        new_solution = simpledialog.askstring('Teach me','I don\'t know!Wha\'s the solution of '+ytt+'?')
        the_physical_condition[ytt] = new_solution
        write_to_file(ytt,new_solution)
root.mainloop()

            
            




from tkinter import Tk,messagebox,simpledialog

def get_task():
    task= simpledialog.askstring('Task','Do you want to encrypt or decrypt?')
    return task

def get_message():
    message= simpledialog.askstring('Message','Enter the secret message: ')
    return message

def is_even(number):
    return number % 2 == 0

def get_even_leters(message):
    even_leters = []
    for counter in range(0,len(message)):
        if is_even(counter):
            even_leters.append(message[counter])
    return even_leters

def get_odd_leters(message):
    odd_leters = []
    for counter in range(0,len(message)):
        if not is_even(counter):
            odd_leters.append(message[counter])
    return odd_leters
def swap_leters(message):
    leter_list = []
    if not is_even(len(message)):
        message=message + 'X'
    even_leters = get_even_leters(message)
    odd_leters = get_odd_leters(message)
    for counter in range(0,int(len(message)/2)):
        leter_list.append(odd_leters[counter])
        leter_list.append(even_leters[counter])
    new_message = ''.join(leter_list)
    return new_message
        
root=Tk()
root.withdraw()

while True:
    task = get_task()
    if task == 'encrypt':
        message = get_message()
        encrypted = swap_leters(message)
        messagebox.showinfo('Cliphertext of the secret is: ',encrypted)
    elif task == 'decrypt':
        message = get_message()
        decrypted = swap_leters(message)
        messagebox.showinfo('Plaintext of the secret is: ',decrypted)
    else:
        break

root.mainloop()

    



import os
def HELLOWORLD():
    display = 'print(\'hello,world\')\nperson=input(\'what\\\'s your name?\')\nprint(\'hello,\',person)'
    displayString = '结果：\n>>>print(\'hello,world\')\nhello,world\n>>>person=input(\'what\\\'s your name?\')\nwhat\'s your name?copiseded(你可以输入你自己的名字)\nprint(\'hello,\',person)\nhello,lin'
    print(display)
    print(displayString)
def IF_ELSE():
    print('weather = input(\'How is the weather?rain/sunny/cold: \')\nif weather == \'rain\':\n    print(\'I\\\'m disappointed\')\nelif weather == \'cold\':    print(\'I\\\'m disappointed\')else:\n    print(\'Come on the play with me.\')')
    print('结果：\n>>>weather = input(\'How is the weather?rain/sunny/cold: \')\nHow is the weather?rain/sunny/cold:\n>>>rain\nI\'m disappointed')
IF_ELSE()



import turtle as t
from random import randint,random
def draw_squriel(steps,size,col,x,y):
    t.penup()
    t.goto(x,y)
    t.pendown()
    t.color(col)
    t.begin_fill()
    angle = 90 - (90/steps)
    for i in range(steps):
        t.forward(size)
        t.left(angle)
    t.end_fill()
t.Screen().bgcolor('dark blue')
t.hideturtle()
t.speed('fastest')
def draw_squriel_here(x,y):
    ranSps = randint(4,10)*4 + 2
    ranSize = randint(10,50)
    rancol = (random(),random(),random())
    draw_squriel(ranSps,ranSize,rancol,x,y)
t.onscreenclick(draw_squriel_here,1,False)



person=input('What\'s you name?:\n')
print('hello, '+person)

def check_guess(guess,English_answer,Chinese_answer):
    global score
    still_guessing=True
    attempt=0
    while still_guessing and attempt<3:
        if guess.lower()==Chinese_answer.lower() or guess.lower()==English_answer.lower():
            print('Correct answer!')
            score=score+1
            still_guessing = False
        else:
            if attempt<2:
                guess = input('Sorry wrong answer,Try again.')
            attempt = attempt + 1
            
    if attempt == 3:
        print('The correct answer is '+ English_answer,"正确答案是" + Chinese_answer)
        
score=0
print('Guess the animals')
guess1=input('Which animal lives at the north pole?:\n')
check_guess(guess1,'polar bear','北极熊')
guess2=input('Which is the fastest land animal?:\n')
check_guess(guess2,'cheetah','猎豹')
guess3=input('Which is the largest animal?:\n')
check_guess(guess3,'blue whale','蓝鲸')

print('your score is %s .'% (score))



import turtle
from itertools import cycle

colors=cycle(['red','orange','yellow','green','blue','purple'])

def draw_circle(size,angle,shift):
    turtle.pencolor(next(colors))
    turtle.circle(size)
    turtle.right(angle)
    turtle.forward(shift)
    draw_circle(size + 5,angle + 1,shift + 1)
    
turtle.shape('turtle')
turtle.bgcolor('Thistle')
turtle.speed('fastest')
turtle.pensize(4)
draw_circle(30,0,1)



import random
import time
from tkinter import Tk,Canvas,HIDDEN,NORMAL

print('player1_snap:Press \'q\',player2_snap:Press \'p\'')
def next_shape():
    global shape
    global previous_color
    global current_color
    global shape_speed

    previous_color = current_color

    c.delete(shape)
    if len(shapes) > 0:
        shape = shapes.pop()
        c.itemconfigure(shape,state=NORMAL)
        current_color = c.itemcget(shape,'fill')
        root.after(shape_speed,next_shape)
        shape_speed = shape_speed - 25
        if shape_speed < 100:
            shape_speed = 100

    else:
        c.unbind('q')
        c.unbind('p')
        if player1_score > player2_score:
            c.create_text(200,200,text='winner: Player1')
        elif player2_score > player1_score:
            c.create_text(200,200,text='winner:Player2')
        else:
            c.create_text(200,200,text='Draw')
        c.pack()
def snap(event):
    global shape
    global player1_score
    global player2_score
    global previous_color
    valid = False

    c.delete(shape)

    if previous_color == current_color:
        valid = True

    if valid:
        if event.char =='q':
            player1_score = player1_score+1
        else:
            player2_score = player2_score+1
        shape = c.create_text(200,200,text='SNAP!You score 1 point!')
        previous_color = ''
    else:
        if event.char =='q':
            player1_score = player1_score-1
        else:
            player2_score = player2_score-1
        shape = c.create_text(200,200,text='WRONG!You lose 1 point!')
    c.pack()
    root.update_idletasks()
    time.sleep(1)
    
root = Tk()
root.title('snap')
c = Canvas(root,width=400,height=400)

shapes = []

circle = c.create_oval(35,20,365,350,outline='black',fill='black',state=HIDDEN)
shapes.append(circle)
circle = c.create_oval(35,20,365,350,outline='red',fill='red',state=HIDDEN)
shapes.append(circle)
circle = c.create_oval(35,20,365,350,outline='green',fill='green',state=HIDDEN)
shapes.append(circle)
circle = c.create_oval(35,20,365,350,outline='blue',fill='blue',state=HIDDEN)
shapes.append(circle)

rectangle = c.create_rectangle(35,100,365,270,outline='black',fill='black',state=HIDDEN)
shapes.append(rectangle)
rectangle = c.create_rectangle(35,100,365,270,outline='red',fill='red',state=HIDDEN)
shapes.append(rectangle)
rectangle = c.create_rectangle(35,100,365,270,outline='green',fill='green',state=HIDDEN)
shapes.append(rectangle)
rectangle = c.create_rectangle(35,100,365,270,outline='blue',fill='blue',state=HIDDEN)
shapes.append(rectangle)

square = c.create_rectangle(35,20,365,350,outline='black',fill='black',state=HIDDEN)
shapes.append(square)
square = c.create_rectangle(35,20,365,350,outline='red',fill='red',state=HIDDEN)
shapes.append(square)
square = c.create_rectangle(35,20,365,350,outline='green',fill='green',state=HIDDEN)
shapes.append(square)
square = c.create_rectangle(35,20,365,350,outline='blue',fill='blue',state=HIDDEN)
shapes.append(square)

c.pack()

random.shuffle(shapes)

shape = None
previous_color = 'a'
current_color = 'b'
player1_score = 0
player2_score = 0

root.after(3000,next_shape)
c.bind('q',snap)
c.bind('p',snap)
c.focus_set()
shape_speed=1000

root.mainloop()





import setuptools

with open("README.rst", "r",encoding = "UTF-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="MHCInc",
    version="0.2.5",
    author="Mhc-inc",
    author_email="Wf6350177@163.com",
    description="改进漏洞：将使用模块功能时找不到文件优化",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://pypi.org/project/MHCInc/",
    project_urls={
        "Bug Tracker": "https://github.com/Mhc-inc/MHCInc/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['lxml',
                  'requests','bs4','pygame'],
    package_dir={"": "MHCInc"},
    packages=setuptools.find_packages(where="MHCInc"),
    python_requires=">=3.9",
)



import cmath
def addOne(number):
    return number + 1
def addDouble(number):
    return number * 2
def add(distance,number):
    return number + distance
def stepUpTimes(times,number):
    return number + times * number
def numberTimes(times,number):
    return number * times
def aNumberOfFactorial(number):
    result = 1
    for item in range(1,number+1):
        result = result * item
    return result
def squareRoot_negativeNumber(number):
    num_sqrt = cmath.sqrt(number)
    copiseded_numbertimes = '{0} 的平方根为 {1:0.3f}+{2:0.3f}j'.format(number,
    num_sqrt.real,num_sqrt.imag)
    return copiseded_numbertimes
def 四舍五入(n):
    string = str(n)
    array = list(string)
    last = int(array[len(array)-1])
    if last <= 4:
        return string
    else:
        if n < 10:
            return "10"
        else:
            array[len(array)-1] = "0"
            second = int(array[len(array)-2])
            second += 1
            array[len(array)-2] = str(second)
            return "".join(array)
def 猜出你的年龄():
    print("在1~10内选一个数：")
    print("下面，将你生日转换为下面格式:\n\"你的生日几月几号+0\"，\n如4月4日，就是\"440\"")
    print("OK，接下来，将这个数乘2加5，\n然后将结果乘50，\n回答，这个数是什么")
    answer = input("回答我：\n")
    number = int(answer)
    numList = [1,2,3,4,5,6,7,8,9,10]
    for i in numList:
        if not answer.isalnum or int(answer) != (i * 2 + 5) * 50:
            print('不能输入范围外的内容')
            Error = {"错误":"用户输入范围外内容"}
            return [None,None,{"Error":Error}]
            break
        else:
            number += 1772
            answer = input("输入你出生的年份\n别以为前面在装虚弄假\n因为我会猜出你猜的数加年龄：\n")
            if len(answer) > 4 or len(answer) < 4:
                print('不能输入范围外的数')
            else:
                number -= int(answer)
                List = list(str(number))
                return [List[0],List[1]+List[2],{"Error":None}]
#result = 猜出你的年龄()
#if result[2]["Error"] == None:
    #print("你一开始选的数字是：\n{}\n你的年龄是：\n{}".format(result[0],result[1]))
#else:
    #print("错误")
def squareRoot_positiveNumber(number):
    num_sqrt = number ** 0.5
    copiseded_number = ' %0.3f 的平方根为 %0.3f'%(number ,num_sqrt)
    return copiseded_number
def squareOfANumber(number):
    result = number * number
    return result
def division(Divisor,Dividend):
    result = 'the quotient is: %s'% (Dividend/Divisor)
    return result
def divisionOne(Dividend):
    result = 'the quotient is: %s'% (Dividend/1)
    return result
def toThePowerOfNumber_positiveNumber(number,Power):
    num_sqrt = number ** Power
    copiseded_number = ' %0.3f 的 %0.3f 次方为 %0.3f'%(number,Power,num_sqrt)
    return copiseded_number
def toThePowerOfNumber_negativeNumber(number,Power):
    num_sqrt = number ** Power
    copiseded_numbertimes = '{0} 的 {1:0.3f}次方为 {2:0.3f}+{3:0.3f}j'.format(number,Power,
    num_sqrt.real,num_sqrt.imag)
    return copiseded_numbertimes
def subtraction(substractor,subtrahend):
    copiseded_number = subtrahend - substractor
    return copiseded_number
def subtractionOne(subtrahend):
    copiseded_number = subtrahend - 1
    return copiseded_number
def primeNumber_list_1_997_MinMaxNumber():
    copiseded_number = [29,71,113,173,229,281,349,409,463,541,601,659,733,809,863,941,2,31,73,127,179,233,283,353,419,467,547,607,661,739,811,877,947,3,37,79,131,181,239,293,359,421,479,557,613,673,743,821,881,953,5,41,83,137,191,241,307,367,431,487,563,617,677,751,823,883,967,7,43,89,139,193,251,311,373,433,491,569,619,683,757,827,887,971,11,47,97,149,197,257,313,379,439,499,571,631,691,761,829,907,977,13,53,101,151,199,263,317,383,443,503,577,641,701,769,839,911,983,17,59,103,157,211,269,331,389,449,509,587,643,709,773,853,919,991,19,61,107,163,223,271,337,397,457,521,593,647,719,787,857,929,997,23,67,109,167,277,347,401,461,523,599,653,727,797,859,937,168]
    List_min = min(copiseded_number)
    List_max = max(copiseded_number)
    print('max:',List_max)
    print('min:',List_min)
    return copiseded_number



import turtle as t
from random import randint,random

def draw_star(points,size,col,x,y):
    t.penup()
    t.goto(x,y)
    t.pendown()
    angle = 180 - (180/points)
    t.color(col)
    t.begin_fill()
    for i in range(points):
        t.forward(size)
        t.right(angle)
    t.end_fill()

def draw_star_here(x,y):
    ranPts = randint(2,5)*2 + 1
    ranSize = randint(10,50)
    rancol = (random(),random(),random())
    draw_star(ranPts,ranSize,rancol,x,y)


#Main code
t.Screen().bgcolor('dark blue')
t.hideturtle()
t.speed('fastest')

'''
while True:
    ranPts = randint(2,5)*2 + 1
    ranSize = randint(10,50)
    rancol = (random(),random(),random())
    ranX = randint(-350,300)
    ranY = randint(-250,250)
    draw_star(ranPts,ranSize,rancol,ranX,ranY)
'''
t.onscreenclick(draw_star_here)



import random
def guessGame_1_10():
    number = random.randint(1,10)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100():
    number = random.randint(1,100)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_1000():
    number = random.randint(1,1000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_10000():
    number = random.randint(1,10000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100000():
    number = random.randint(1,100000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_1000000():
    number = random.randint(1,1000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_10000000():
    number = random.randint(1,10000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100000000():
    number = random.randint(1,100000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_1000000000():
    number = random.randint(1,10000000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_10000000000():
    number = random.randint(1,10000000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_100000000000():
    number = random.randint(1,100000000000)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_999999999999():
    number = random.randint(1,999999999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_9():
    number = random.randint(1,9)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_99():
    number = random.randint(1,99)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_999():
    number = random.randint(1,999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_9999():
    number = random.randint(1,9999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_99999():
    number = random.randint(1,99999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_999999():
    number = random.randint(1,999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_9999999():
    number = random.randint(1,9999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_99999999():
    number = random.randint(1,99999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_999999999():
    number = random.randint(1,999999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_9999999999():
    number = random.randint(1,9999999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))
def guessGame_1_99999999999():
    number = random.randint(1,99999999999)

    guess = input('请输入你的数字:')

    if number == int(guess):
        print('太棒了，你猜对了!')
    else:
        print('sorry wrong,the collect int is: '+str(number))



import subprocess
import requests
import os
from lxml import etree
from bs4 import BeautifulSoup
if not os.path.exists("MHCInc"):
        os.mkdir("MHCInc")
path1 = "MHCInc/200bpm%E6%AD%BB%E4%BA%A1%E4%B9%8B%E6%9B%B2 2.flac"
path2 = "MHCInc/8bq.png"
if not os.path.exists(path1):
        url = "https://wx.mail.qq.com/ftn/download?func=3&key=9d9ce332085a5ef6afef4f3235663735be2bd73237663735474c54530605550756564c5400005318560050571a040507014e0251530705045555550b5304063550535150470b12705446207612247510275744707643760447265517755f120d20462404125f75102051410019005b5401776f9efe5f9b05326c47ff309e0fc683d8c088dbe2&code=bca27f75&k=9d9ce332085a5ef6afef4f3235663735be2bd73237663735474c54530605550756564c5400005318560050571a040507014e0251530705045555550b5304063550535150470b12705446207612247510275744707643760447265517755f120d20462404125f75102051410019005b5401776f9efe5f9b05326c47ff309e0fc683d8c088dbe2&fweb=1&cl=1"
        request = requests.get(url)
        #print(request.content.decode("utf-8"))
        html0 = etree.HTML(request.content.decode("utf-8"))
        block = html0.xpath("//*[@nonce]")[5].xpath("text()")[0].split(" = ")[9].split("\"")[1]
        with open(path1,"wb") as f:
                f.write(requests.get(block).content)

if not os.path.exists(path2):
        url = "https://wx.mail.qq.com/ftn/download?func=3&key=cbce6d375b080bfaf9bd1b3766346239a7f9203764346239111e505652015100045018565055501400540600490c03000c1c02025500575c55020052575165390c534419145a052df0f09f5c32b2183db56a152f367f46f7bda82f8e&code=4157d4b9&k=cbce6d375b080bfaf9bd1b3766346239a7f9203764346239111e505652015100045018565055501400540600490c03000c1c02025500575c55020052575165390c534419145a052df0f09f5c32b2183db56a152f367f46f7bda82f8e&fweb=1&cl=1"
        request = requests.get(url)
        #print(request.content.decode("utf-8"))
        html0 = etree.HTML(request.content.decode("utf-8"))
        block = html0.xpath("//*[@nonce]")[5].xpath("text()")[0].split(" = ")[9].split("\"")[1]
        with open(path2,"wb") as f:
                f.write(requests.get(block).content)
class module:
    def main():
        from MHCInc import copyright
        copyright.copyright_Swift()
    def caterpillar():
        from MHCInc import caterpillar
    def 单词九连猜():
        from MHCInc import 单词九连猜
    def nineWordGuessing():
        from MHCInc import 单词九连猜
    def 加密消息():
        from MHCInc import 加密消息
    def secretMessage():
        from MHCInc import 加密消息
    def snap():
        from MHCInc import 快照抓拍
    def 快照抓拍():
        from MHCInc import 快照抓拍
    def 螺旋万花筒():
        from MHCInc import 螺旋万花筒
    def spiralKaleidoscope():
        from MHCInc import 螺旋万花筒
    def 星光夜空():
        from MHCInc import 星光夜空
    def starlightNight():
        from MHCInc import 星光夜空
    def 圆筒万花筒():
        from MHCInc import 圆筒万花筒
    def cylinderKaleidoscope():
        from MHCInc import 圆筒万花筒
    def animal_guess():
        from MHCInc import animal_guess
    def caterpillar2():
        from MHCInc import caterpillar2
    def copyright():
        from MHCInc import copyright
    def eggCatcherPerfect():
        from MHCInc import egg_catcher_perfect
    def eggCatcher():
        from MHCInc import egg_catcher
    def GuessGame():
        from MHCInc import GuessGame
    def GuessGameEasy():
        from MHCInc import GuessGameEasy
    def GuessGameSecondary():
        from MHCInc import GuessGameSecondary
    def matchmaker():
        from MHCInc import matchmaker
    def MITLicense():
        from MHCInc import MITLicense
    def PHYSICAL_CONDITION_APPLET():
        from MHCInc import PHYSICAL_CONDITION_APPLET
    def Python3学习示例():
        from MHCInc import Python3学习示例
    from MHCInc import random
    def rectangle():
        from MHCInc import rectangle
    def robotBuilder():
        from MHCInc import robot_builder
    def screenPet():
        from MHCInc import screen_pet
    from MHCInc import swift




from tkinter import HIDDEN,NORMAL,Tk,Canvas
import random
import time

def change_color():
    pet_colors=['SkyBlue1','tomato','yellow','purple','green','orange']
    c.body_color = random.choice(pet_colors)
    c.itemconfigure(body,outline=c.body_color,fill=c.body_color)
    c.itemconfigure(ear_left,outline=c.body_color,fill=c.body_color)
    c.itemconfigure(ear_right,outline=c.body_color,fill=c.body_color)
    c.itemconfigure(foot_left,outline=c.body_color,fill=c.body_color)
    c.itemconfigure(foot_right,outline=c.body_color,fill=c.body_color)
    root.after(5000,change_color)
    
def toggle_eyes():
    current_color = c.itemcget(eye_left,'fill')
    new_color=c.body_color if current_color=='white' else 'white'
    current_state=c.itemcget(pupil_left,'state')
    new_state=NORMAL if current_state==HIDDEN else HIDDEN
    c.itemconfigure(pupil_left,state=new_state)
    c.itemconfigure(pupil_right,state=new_state)
    c.itemconfigure(eye_left,fill=new_color)
    c.itemconfigure(eye_right,fill=new_color)

def blink():
    toggle_eyes()
    root.after(250,toggle_eyes)
    root.after(5000,blink)

def toggle_tongue():
    if not c.tongue_out:
        c.itemconfigure(tongue_tip,state=NORMAL)
        c.itemconfigure(tongue_main,state=NORMAL)
        c.tongue_out=True
    else:
        c.itemconfigure(tongue_tip,state=HIDDEN)
        c.itemconfigure(tongue_main,state=HIDDEN)
        c.tongue_out=False
        
def toggle_pupils():
    if not c.eyes_crossed:
        c.move(pupil_left,10,-5)
        c.move(pupil_right,-10,-5)
        c.eyes_crossed=True
    else:
        c.move(pupil_left,-10,5)
        c.move(pupil_right,10,5)
        c.eyes_crossed=False

def cheeky(event):
    toggle_tongue()
    toggle_pupils()
    hide_happy(event)
    root.after(1000,toggle_tongue)
    root.after(1000,toggle_pupils)
    return

def show_happy(event):
    if (20 <= event.x <=350) and (20 <= event.y <=350):
        c.itemconfigure(cheek_left,state=NORMAL)
        c.itemconfigure(cheek_right,state=NORMAL)
        c.itemconfigure(mouth_happy,state=NORMAL)
        c.itemconfigure(mouth_normal,state=HIDDEN)
        c.itemconfigure(mouth_sad,state=HIDDEN)
        c.happy_level=10
    return

def hide_happy(event):
        c.itemconfigure(cheek_left,state=HIDDEN)
        c.itemconfigure(cheek_right,state=HIDDEN)
        c.itemconfigure(mouth_happy,state=HIDDEN)
        c.itemconfigure(mouth_normal,state=HIDDEN)
        c.itemconfigure(mouth_sad,state=HIDDEN)
        return


def sad():
    if c.happy_level==0:
        c.itemconfigure(mouth_happy,state=HIDDEN)
        c.itemconfigure(mouth_normal,state=HIDDEN)
        c.itemconfigure(mouth_sad,state=NORMAL)
    else:
        c.happy_level -= 1
    root.after(5000,sad)


root=Tk()
root.title("PSYDUCK MADE GAMING")
c=Canvas(root,width=400,height=400)
c.configure(bg='dark blue',highlightthickness=0)
c.create_text(50,50,anchor='s',fill='tomato',font='alrial 16',\
              text='双击-淘气'+'\n'+'轻抚-快乐'+'\n'+ '??-悲伤')

c.body_color='skyblue1'
body=c.create_oval(35,20,365,350,outline=c.body_color,fill=c.body_color)
ear_left=c.create_polygon(75,80,75,10,165,70,outline=c.body_color,fill=c.body_color)
ear_right=c.create_polygon(225,45,325,10,320,70,outline=c.body_color,fill=c.body_color)
foot_left=c.create_oval(65,320,145,360,outline=c.body_color,fill=c.body_color)
foot_right=c.create_oval(250,320,330,360,outline=c.body_color,fill=c.body_color)

eye_left=c.create_oval(130,110,160,170,outline='black',fill='white')
pupil_left=c.create_oval(140,145,150,155,outline='black',fill='black')
eye_right=c.create_oval(230,110,260,170,outline='black',fill='white')
pupil_right=c.create_oval(240,145,250,155,outline='black',fill='black')

mouth_normal=c.create_line(170,250,200,272,230,250,smooth=1,width=2,state=NORMAL)
mouth_happy=c.create_line(170,250,200,282,230,250,smooth=1,width=2,state=HIDDEN)
mouth_sad=c.create_line(170,250,200,232,230,250,smooth=1,width=2,state=HIDDEN)
tongue_main=c.create_rectangle(170,250,230,290,outline='red',fill='red',state=HIDDEN)
tongue_tip=c.create_oval(170,285,230,300,outline='red',fill='red',state=HIDDEN)

cheek_left=c.create_oval(70,180,120,230,outline='pink',fill='pink',state=HIDDEN)
cheek_right=c.create_oval(280,180,330,230,outline='pink',fill='pink',state=HIDDEN)

mouth_normal=c.create_line(170,250,200,272,230,250,smooth=1,width=2,state=NORMAL)


c.pack()

c.bind('<Motion>',show_happy)
c.bind('<Leave>',hide_happy)
c.bind('<Double-1>',cheeky)

c.happy_level=10
c.eyes_crossed=False
c.tongue_out=False

root.after(1000,blink)
root.after(5000,change_color)
root.mainloop()
